Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(977)

Unified Diff: cc/tiles/tile_manager.cc

Issue 1202843008: cc: Fix BytesPerPixel issue and refactor. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed Android build break. Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/tiles/tile.cc ('k') | cc/tiles/tile_manager_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/tiles/tile_manager.cc
diff --git a/cc/tiles/tile_manager.cc b/cc/tiles/tile_manager.cc
index 23d2eca12bc23f35ee754226ba18be01066341ca..545866e3f3e52b048b85b03a19120c5ab06cee52 100644
--- a/cc/tiles/tile_manager.cc
+++ b/cc/tiles/tile_manager.cc
@@ -1045,9 +1045,10 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes,
TileManager::MemoryUsage TileManager::MemoryUsage::FromConfig(
const gfx::Size& size,
ResourceFormat format) {
// We can use UncheckedMemorySizeBytes here since this is used with a tile
// size which is determined by the compositor (it's at most max texture size).
- return MemoryUsage(Resource::UncheckedMemorySizeBytes(size, format), 1);
+ return MemoryUsage(ResourceUtil::UncheckedSizeInBytes<size_t>(size, format),
+ 1);
}
// static
« no previous file with comments | « cc/tiles/tile.cc ('k') | cc/tiles/tile_manager_unittest.cc » ('j') | no next file with comments »
@@ -1045,9 +1045,10 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes,
const gfx::Size& size,
ResourceFormat format) {
- // We can use UncheckedMemorySizeBytes here since this is used with a tile
+ // We can use UncheckedSizeInBytes here since this is used with a tile
// size which is determined by the compositor (it's at most max texture size).

Powered by Google App Engine
This is Rietveld 408576698